Experimental "audio-fetching" script added
[core.git] / index.php
index 3cca6d52f2f0ac6a4f0dac63d963a25bf24d2e23..753e54afef0c09cffd916413bb5bc1b00a937ca9 100644 (file)
--- a/index.php
+++ b/index.php
@@ -6,6 +6,7 @@ namespace CoreFramework\EntryPoint;
 use CoreFramework\Bootstrap\FrameworkBootstrap;
 use CoreFramework\Configuration\FrameworkConfiguration;
 use CoreFramework\Factory\ObjectFactory;
+use CoreFramework\Filesystem\FileNotFoundException;
 use CoreFramework\Helper\Application\ApplicationHelper;
 use CoreFramework\Localization\LanguageSystem;
 use CoreFramework\Loader\ClassLoader;
@@ -57,7 +58,7 @@ final class ApplicationEntryPoint {
         * @return      void
         * @todo        This method is old code and needs heavy rewrite and should be moved to ApplicationHelper
         */
-       public static final function app_exit ($message = '', $code = FALSE, $extraData = '', $silentMode = FALSE) {
+       public static final function app_exit ($message = '', $code = false, $extraData = '', $silentMode = false) {
                // Is this method already called?
                if (isset($GLOBALS['app_die_called'])) {
                        // Then output the text directly
@@ -65,7 +66,7 @@ final class ApplicationEntryPoint {
                } // END - if
 
                // This method shall not be called twice
-               $GLOBALS['app_die_called'] = TRUE;
+               $GLOBALS['app_die_called'] = true;
 
                // Is a message set?
                if (empty($message)) {
@@ -77,7 +78,7 @@ final class ApplicationEntryPoint {
                $configInstance = FrameworkConfiguration::getSelfInstance();
 
                // Do we have debug installation?
-               if (($configInstance->getConfigEntry('product_install_mode') == 'productive') || ($silentMode === TRUE)) {
+               if (($configInstance->getConfigEntry('product_install_mode') == 'productive') || ($silentMode === true)) {
                        // Abort here
                        exit();
                } // END - if
@@ -90,7 +91,7 @@ final class ApplicationEntryPoint {
                $templateInstance = NULL;
 
                // Get response instance
-               $responseInstance = ApplicationHelper::getSelfInstance()->getResponseInstance();
+               $responseInstance = FrameworkBootstrap::getResponseInstance();
 
                // Is the template engine loaded?
                if ((class_exists($tpl)) && (is_object($languageInstance))) {
@@ -199,15 +200,15 @@ final class ApplicationEntryPoint {
                                // Debug message
                                //* NOISY-DEBUG: */ printf('[%s:%d]: realPath[%s]=%s' . PHP_EOL, __METHOD__, __LINE__, gettype($realPath), $realPath);
 
-                               // Is it FALSE?
-                               if ($realPath === FALSE) {
+                               // Is it false?
+                               if ($realPath === false) {
                                        // Then, not found.
                                        continue;
                                } // END - if
 
// First create full-qualified file name (FQFN) to framework/config.inc.php
                                $fqfn = sprintf(
-                                       '%s%sframework%sconfig.inc.php',
+                                       '%s%sframework%sconfig-global.php',
                                        $realPath,
                                        DIRECTORY_SEPARATOR,
                                        DIRECTORY_SEPARATOR,
@@ -258,21 +259,30 @@ final class ApplicationEntryPoint {
         */
        public static final function main () {
                // Load bootstrap file
-               require self::detectFrameworkPath() . 'bootstrap/bootstrap.inc.php';
+               require sprintf('%sbootstrap%sbootstrap.inc.php', self::detectFrameworkPath(), DIRECTORY_SEPARATOR);
 
                /*
-                * Initial bootstrap is done, continue with parsing parameters and
-                * look for 'app'.
+                * Initial bootstrap is done, continue with initialization of
+                * framework.
                 */
-               FrameworkBootstrap::parseParameters();
+               FrameworkBootstrap::initFramework();
+
+               // Next initialize the detected application
+               FrameworkBootstrap::prepareApplication();
+
+               /*
+                * Last step is to start the application, this will also initialize and
+                * register the application instance in registry.
+                */
+               FrameworkBootstrap::startApplication();
        }
 }
 
 // Developer mode active? Comment out if no dev!
-define('DEVELOPER', TRUE);
+define('DEVELOPER', true);
 
 // Log all exceptions (only debug! This option can create large error logs)
-//define('LOG_EXCEPTIONS', TRUE);
+//define('LOG_EXCEPTIONS', true);
 
 //xdebug_start_trace();
@@ -199,15 +200,15 @@ final class ApplicationEntryPoint {
                                } // END - if
 
-                               // First create full-qualified file name (FQFN) to framework/config.inc.php
+                               // First create full-qualified file name (FQFN) to framework/config-global.php
                                $fqfn = sprintf(